@@ -1,6 +1,5 @@
 package Net::Google::Spreadsheets::UserAgent;
 use Moose;
-use namespace::clean -except => 'meta';
 use Carp;
 use LWP::UserAgent;
 use HTTP::Headers;
@@ -25,24 +24,21 @@ has ua => (
     isa => 'LWP::UserAgent',
     is => 'ro',
     required => 1,
-    lazy_build => 1,
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        my $ua = LWP::UserAgent->new(
+            agent => $self->source,
+        );
+        $ua->default_headers(
+            HTTP::Headers->new(
+                Authorization => sprintf('GoogleLogin auth=%s', $self->auth),
+                GData_Version => 2,
+            )
+        );
+        return $ua;
+    }
 );
-sub _build_ua {
-    my $self = shift;
-    my $ua = LWP::UserAgent->new(
-        agent => $self->source,
-        requests_redirectable => [],
-    );
-    $ua->default_headers(
-        HTTP::Headers->new(
-            Authorization => sprintf('GoogleLogin auth=%s', $self->auth),
-            GData_Version => '3.0',
-        )
-    );
-    return $ua;
-}
-
-__PACKAGE__->meta->make_immutable;
 
 sub request {
     my ($self, $args) = @_;
@@ -58,69 +54,60 @@ sub request {
             $req->header(@pair);
         }
     }
-    my $res = eval {$self->ua->request($req)};
-    if ($@ || !$res->is_success) {
-        die sprintf("request for '%s' failed:\n\t%s\n\t%s\n\t", $uri, ($@ || $res->status_line), ($! || $res->content));
-    }
-    my $type = $res->content_type;
-    if ($res->content_length && $type !~ m{^application/atom\+xml}) {
-        die sprintf("Content-Type of response for '%s' is not 'application/atom+xml':  %s", $uri, $type);
-    }
-    if (my $res_obj = $args->{response_object}) {
-        my $obj = eval {$res_obj->new(\($res->content))};
-        croak sprintf("response for '%s' is broken: %s", $uri, $@) if $@;
-        return $obj;
+    my $res = $self->ua->request($req);
+    unless ($res->is_success) {
+        die sprintf("request for '%s' failed: %s", $uri, $res->status_line);
     }
     return $res;
 }
 
 sub feed {
     my ($self, $url, $query) = @_;
-    return $self->request(
+    my $res = $self->request(
         {
             uri => $url,
             query => $query || undef,
-            response_object => 'XML::Atom::Feed',
         }
     );
+    return XML::Atom::Feed->new(\($res->content));
 }
 
 sub entry {
     my ($self, $url, $query) = @_;
-    return $self->request(
+    my $res = $self->request(
         {
             uri => $url,
             query => $query || undef,
-            response_object => 'XML::Atom::Entry',
         }
     );
+    return XML::Atom::Entry->new(\($res->content));
 }
 
 sub post {
     my ($self, $url, $entry, $header) = @_;
-    return $self->request(
+    my $res = $self->request(
         {
             uri => $url,
             content => $entry->as_xml,
             header => $header || undef,
             content_type => 'application/atom+xml',
-            response_object => ref $entry,
         }
     );
+    return (ref $entry)->new(\($res->content));
 }
 
 sub put {
     my ($self, $args) = @_;
-    return $self->request(
+    my $res = $self->request(
         {
             method => 'PUT',
             uri => $args->{self}->editurl,
             content => $args->{entry}->as_xml,
             header => {'If-Match' => $args->{self}->etag },
             content_type => 'application/atom+xml',
-            response_object => 'XML::Atom::Entry',
         }
     );
+    return XML::Atom::Entry->new(\($res->content));
 }
 
 1;
@@ -132,9 +119,9 @@ Net::Google::Spreadsheets::UserAgent - UserAgent for Net::Google::Spreadsheets.
 
 =head1 SEE ALSO
 
-L<http://code.google.com/intl/en/apis/spreadsheets/docs/3.0/developers_guide_protocol.html>
+L<http://code.google.com/intl/en/apis/spreadsheets/docs/2.0/developers_guide_protocol.html>
 
-L<http://code.google.com/intl/en/apis/spreadsheets/docs/3.0/reference.html>
+L<http://code.google.com/intl/en/apis/spreadsheets/docs/2.0/reference.html>
 
 L<Net::Google::AuthSub>
 
